@@ -1,7 +1,7 @@
 from dataclasses import dataclass
 from datetime import datetime
 import psycopg2
-from geo_ops import config
+from dpl_geodb.geo_ops import config
 
 @dataclass
 class PictureReference:
